==> openGion7.2.9.0_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GEA10S.sql <==
/****************************************************************************/
/* GEA10 ( ﾕｰｻﾞｰ定義 )                                                      */
/*                                                                          */
/* Created : 2018/09/28 16:03:35                                            */
/****************************************************************************/

CREATE TABLE GEA10 (
   SYSTEM_ID    VARCHAR (   10 )                            NOT NULL            /*  10 ｼｽﾃﾑID           */
 , USERID       VARCHAR (   10 )                            NOT NULL            /*  20 ﾕｰｻﾞｰID          */
 , PASSWD       VARCHAR (   32 )                            NOT NULL            /*  30 ﾊﾟｽﾜｰﾄﾞ          */
 , LANG         VARCHAR (    2 )                            NOT NULL            /*  40 言語             */
 , NAME_JA      VARCHAR (  200 )                                                /*  50 名称             */
 , ROLES        VARCHAR ( 2000 )                            NOT NULL            /*  60 ﾛｰﾙｽﾞ            */
 , DROLES       VARCHAR ( 2000 )                                                /*  70 ﾃﾞｰﾀﾛｰﾙｽﾞ        */
 , COMMENTS     VARCHAR (  500 )                                                /*  80 ｺﾒﾝﾄ             */
 , DYPASSWD     VARCHAR (   14 )                                                /*  90 ﾊﾟｽﾜｰﾄﾞ変更日時  */
 , DYVALID      VARCHAR (    8 )        DEFAULT '99999999'  NOT NULL            /* 100 有効日           */
 , FGDEFAULT    VARCHAR (    1 )        DEFAULT '0'                             /* 110 ﾛｸﾞｲﾝFG          */
 , MAILAD       VARCHAR (  100 )                                                /* 120 ﾒｰﾙｱﾄﾞﾚｽ         */
 , UNIQ         BIGINT                                      NOT NULL            /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR (    1 )        DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR (   14 )                                                /* 820 登録日時         */
 , PGSET        VARCHAR (   10 )                                                /* 830 作成PG           */
 , PGPSET       VARCHAR (   10 )                                                /* 840 作成親PG         */
 , USRSET       VARCHAR (   10 )                                                /* 850 作成者           */
 , DYUPD        VARCHAR (   14 )                                                /* 860 更新日時         */
 , PGUPD        VARCHAR (   10 )                                                /* 870 更新PG           */
 , PGPUPD       VARCHAR (   10 )                                                /* 880 更新親PG         */
 , USRUPD       VARCHAR (   10 )                                                /* 890 更新者           */
);


CREATE SEQUENCE GEA10S00 ;


CREATE TRIGGER GEA10T00 FOR GEA10
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GEA10S00,1 );
  END;

==> openGion7.3.1.3_dev.zip: uap/webapps/ge/db/FIREBIRD/sql/install/01_TABLE/GEA10S.sql <==
/****************************************************************************/
/* GEA10 ( ﾕｰｻﾞｰ定義 )                                                      */
/*                                                                          */
/* Created : 2020/12/16 08:14:13                                            */
/****************************************************************************/

CREATE TABLE GEA10 (
   SYSTEM_ID    VARCHAR (   10 )                            NOT NULL            /*  10 ｼｽﾃﾑID           */
 , USERID       VARCHAR (   10 )                            NOT NULL            /*  20 ﾕｰｻﾞｰID          */
 , PASSWD       VARCHAR (   32 )                            NOT NULL            /*  30 ﾊﾟｽﾜｰﾄﾞ          */
 , LANG         VARCHAR (    2 )                            NOT NULL            /*  40 言語             */
 , NAME_JA      VARCHAR (  200 )                                                /*  50 名称             */
 , ROLES        VARCHAR ( 2000 )                            NOT NULL            /*  60 ﾛｰﾙｽﾞ            */
 , DROLES       VARCHAR ( 2000 )                                                /*  70 ﾃﾞｰﾀﾛｰﾙｽﾞ        */
 , COMMENTS     VARCHAR (  500 )                                                /*  80 ｺﾒﾝﾄ             */
 , DYPASSWD     VARCHAR (   14 )                                                /*  90 ﾊﾟｽﾜｰﾄﾞ変更日時  */
 , DYVALID      VARCHAR (    8 )        DEFAULT '99999999'  NOT NULL            /* 100 有効日           */
 , FGDEFAULT    VARCHAR (    1 )        DEFAULT '0'                             /* 110 ﾛｸﾞｲﾝFG          */
 , MAILAD       VARCHAR (  100 )                                                /* 120 ﾒｰﾙｱﾄﾞﾚｽ         */
 , UNIQ         BIGINT                                      NOT NULL            /* 800 ﾕﾆｰｸｷｰ           */
 , FGJ          VARCHAR (    1 )        DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ         */
 , DYSET        VARCHAR (   14 )                                                /* 820 作成日時         */
 , PGSET        VARCHAR (   10 )                                                /* 830 作成PG           */
 , PGPSET       VARCHAR (   10 )                                                /* 840 作成親PG         */
 , USRSET       VARCHAR (   10 )                                                /* 850 作成者           */
 , DYUPD        VARCHAR (   14 )                                                /* 860 更新日時         */
 , PGUPD        VARCHAR (   10 )                                                /* 870 更新PG           */
 , PGPUPD       VARCHAR (   10 )                                                /* 880 更新親PG         */
 , USRUPD       VARCHAR (   10 )                                                /* 890 更新者           */
);


CREATE SEQUENCE GEA10S00 ;


CREATE TRIGGER GEA10T00 FOR GEA10
  BEFORE INSERT AS 
  BEGIN 
    NEW.UNIQ = GEN_ID( GEA10S00,1 );
  END;
